==> kepler.gl-2.4.0.tgz: package/src/components/side-panel/cloud-storage-dropdown.js <==
// Copyright (c) 2020 Uber Technologies, Inc.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

import React from 'react';
import {PanelHeaderDropdownFactory, Icons} from 'kepler.gl/components';

const CloudStorageItems = [
  {
    label: 'Save',
    icon: Icons.Save2,
    key: 'data',
    onClick: props => props.onSaveMap
  },
  {
    label: 'Settings',
    icon: Icons.Gear,
    key: 'settings',
    onClick: props => props.onExportData
  }
];

const PanelHeaderDropdown = PanelHeaderDropdownFactory();

const CloudStorageDropdown = ({show, onClose}) => {
  return (
    <PanelHeaderDropdown
      items={CloudStorageItems}
      show={show}
      onClose={onClose}
      id="cloud-storage"
    />
  );
};

export default CloudStorageDropdown;

==> kepler.gl-2.5.4.tgz: package/src/components/side-panel/cloud-storage-dropdown.js <==
// Copyright (c) 2021 Uber Technologies, Inc.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

import React from 'react';
import {PanelHeaderDropdownFactory, Icons} from 'components';

const CloudStorageItems = [
  {
    label: 'Save',
    icon: Icons.Save2,
    key: 'data',
    onClick: props => props.onSaveMap
  },
  {
    label: 'Settings',
    icon: Icons.Gear,
    key: 'settings',
    onClick: props => props.onExportData
  }
];

const PanelHeaderDropdown = PanelHeaderDropdownFactory();

const CloudStorageDropdown = ({show, onClose}) => {
  return (
    <PanelHeaderDropdown
      items={CloudStorageItems}
      show={show}
      onClose={onClose}
      id="cloud-storage"
    />
  );
};

export default CloudStorageDropdown;
